@@ -5,6 +5,8 @@
       a program to track moving points in a video frameset
       
     Copyright (C) 2007 Jean-Baptiste Butet <ashashiwa@gmail.com>
+    Copyright (C) 2023 Georges Khaznadar <georgesk@debian.org>
+
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,18 +25,17 @@
 
 class Dbg:
     def __init__(self, verbosite):
-        self.verbosite = verbosite
+        self.verbosite = int(verbosite)
 
     def p(self, niveau, msg):
         """
         affiche un message si la verbosité est suffisante
         """
-        if niveau <= int(self.verbosite):
-            print (msg)
+        if niveau <= self.verbosite:
+            print(msg)
 
     def __str__(self):
         """
         Renvoie une chaîne lisible pour les humains.
         """
-        return "objet debogueur de verbosite %s" % self.verbosite
-    
+        return f"Le débogage a pour verbosité {self.verbosite}"
