@@ -3,7 +3,8 @@
 
 import sys
 import threading
-import os, os.path
+import os
+import os.path
 
 import cv2
 
@@ -19,17 +20,13 @@ class film:
         @param filename le nom d'un fichier video
         """
         self.filename = filename
-        if os.name == 'nt':
-            self.filesize = os.path.getsize(self.filename.encode('cp1252'))
-        else:
-            self.filesize = os.path.getsize(self.filename.encode('utf8'))
+        self.filesize = os.path.getsize(self.filename)
         self.capture = cv2.VideoCapture(self.filename)
 
         t = threading.Thread(target=self.autoTest)
         t.start()
         t.join(5.0)  # attente de 5 secondes au plus
 
-
     def autoTest(self):
         self.ok = False
 
@@ -41,14 +38,11 @@ class film:
             assert 1.0 * self.filesize / self.framecount > 60.0, "fichier aberrant en taille"
             self.ok = True
         except AssertionError:
-            print ("assertion"+str(self.fps)+str(self.framecount))
+            print("assertion"+str(self.fps)+str(self.framecount))
             pass
         except ZeroDivisionError:
-            print ("szero"+str(self.fps)+str(self.framecount))
-
-            pass
-        #if self.filename.split('.')[-1].lower() == "ogv":  # never work with ogv. need encoding.
-        #self.ok = False
+            print("szero"+str(self.fps)+str(self.framecount))
+        return self.ok
 
     def __int__(self):
         return int(self.ok)
@@ -64,4 +58,3 @@ if __name__ == '__main__':
             sys.exit(0)
         else:
             sys.exit(1)
-
